@@ -9,7 +9,7 @@ async fn handler(conn: trillium::Conn) -> trillium::Conn {
 
 
 assert_status!(get("/").on(&handler), 418);
-assert_status!(get("/").on(&handler), StatusCode::ImATeapot);
+assert_status!(get("/").on(&handler), Status::ImATeapot);
 
 let conn = get("/").on(&handler);
 assert_status!(&conn, 418);
@@ -31,7 +31,7 @@ assert_status!(get("/").on(&handler), 418);
 macro_rules! assert_status {
     ($conn:expr, $status:expr) => {{
         use std::convert::TryInto;
-        let expected_status: $crate::StatusCode =
+        let expected_status: $crate::prelude::Status =
             $status.try_into().expect("expected a status code");
 
         match $conn.status() {
@@ -115,11 +115,13 @@ assert_body!(get("/").on(&"beach body"), "winter body");
 
 #[macro_export]
 macro_rules! assert_body {
-    ($conn:expr, $body:expr) => {{
-        let body = $crate::futures_lite::future::block_on($conn.take_response_body_string())
-            .unwrap_or_default();
-        assert_eq!(body.trim_end(), $body.trim_end());
-    }};
+    ($conn:expr, $body:expr) => {
+        match $conn.take_response_body_string().unwrap_or_default() {
+            body => {
+                assert_eq!(body.trim_end(), $body.trim_end());
+            }
+        }
+    };
 }
 
 /**
@@ -150,17 +152,20 @@ assert_body_contains!(get("/").on(&"just a haystack"), "needle");
 
 #[macro_export]
 macro_rules! assert_body_contains {
-    ($conn:expr, $pattern:expr) => {{
-        let body = $crate::futures_lite::future::block_on($conn.take_response_body_string())
-            .unwrap_or_default();
-        assert!(
-            body.contains($pattern),
-            "\nexpected \n`{}`\n to contain `{}`\n but it did not",
-            &body,
-            $pattern
-        );
-        body
-    }};
+    ($conn:expr, $pattern:expr) => {
+        match $conn.take_response_body_string().unwrap_or_default() {
+            body => {
+                assert!(
+                    body.contains($pattern),
+                    "\nexpected \n`{}`\n to contain `{}`\n but it did not",
+                    &body,
+                    $pattern
+                );
+
+                body
+            }
+        }
+    };
 }
 
 /**
@@ -174,17 +179,17 @@ use trillium_testing::prelude::*;
 async fn handler(conn: Conn) -> Conn {
     conn.with_body("just tea stuff here")
         .with_status(418)
-        .with_header(("server", "zojirushi"))
+        .with_header("server", "zojirushi")
 }
 
 assert_response!(get("/").on(&handler), 418);
-assert_response!(get("/").on(&handler), StatusCode::ImATeapot);
+assert_response!(get("/").on(&handler), Status::ImATeapot);
 assert_response!(get("/").on(&handler), 418, "just tea stuff here");
-assert_response!(get("/").on(&handler), StatusCode::ImATeapot, "just tea stuff here");
+assert_response!(get("/").on(&handler), Status::ImATeapot, "just tea stuff here");
 
 assert_response!(
     get("/").on(&handler),
-    StatusCode::ImATeapot,
+    Status::ImATeapot,
     "just tea stuff here",
     "server" => "zojirushi",
     "content-length" => "19"
@@ -214,7 +219,7 @@ macro_rules! assert_response {
     ($conn:expr, $status:expr, $body:expr, $($header_name:literal => $header_value:expr),*) => {
         let mut conn = $conn;
         $crate::assert_response!(&mut conn, $status, $body);
-        $crate::assert_headers!(&mut conn, $($header_name => $header_value),*);
+        $crate::assert_headers!(&conn, $($header_name => $header_value),*);
     };
 
 }
@@ -226,8 +231,8 @@ asserts any number of response headers
 use trillium_testing::prelude::*;
 async fn handler(conn: Conn) -> Conn {
     conn.ok("headers")
-        .with_header(("server", "special-custom-server"))
-        .with_header(("request-id", "10"))
+        .with_header("server", "special-custom-server")
+        .with_header("request-id", "10")
 }
 
 assert_headers!(get("/").on(&handler), "server" => "special-custom-server");
@@ -242,21 +247,33 @@ assert_headers!(
 */
 #[macro_export]
 macro_rules! assert_headers {
-    ($conn:expr, $($header_name:literal => $header_value:expr,)+) => {
-        assert_headers!($conn, $($key => $value),+);
+    (@pair, $conn:expr, $header_name:tt, None) => {
+        match $conn.inner().response_headers().get_str($header_name) {
+            actual => {
+                assert_eq!(actual, None, concat!("for header ", stringify!($header_name)));
+            }
+        };
     };
 
-    ($conn:expr, $($header_name:literal => $header_value:expr),*) => {
-        let mut conn = $conn;
-        let headers = conn.inner_mut().response_headers();
-        $(
-            assert_eq!(
-                headers.get($header_name).map(|h| h.as_str()),
-                Some($header_value),
-                concat!("for header ", $header_name)
-            );
-        )*
+    (@pair, $conn:expr, $header_name:tt, $header_value:expr) => {
+        match ($conn.inner().response_headers().get_str($header_name), $header_value) {
+            (actual, expected) => {
+                assert_eq!(actual, Some(expected), concat!("for header ", stringify!($header_name)));
+            }
+        };
     };
+
+    ($conn:expr, $($header_name:tt => $header_value:tt,)+) => {
+        assert_headers!($conn, $($header_name => $header_value),+);
+    };
+
+    ($conn:expr, $($header_name:tt => $header_value:tt),*) => {
+        match $conn {
+            conn => {
+                $(assert_headers!(@pair, conn, $header_name, $header_value);)*
+            }
+        };
+    }
 }
 
 /**
@@ -271,8 +288,8 @@ it can be used to assert:
 use trillium_testing::prelude::*;
 async fn handler(conn: Conn) -> Conn {
     conn.ok("body")
-        .with_header(("server", "special-custom-server"))
-        .with_header(("request-id", "10"))
+        .with_header("server", "special-custom-server")
+        .with_header("request-id", "10")
 }
 
 assert_ok!(get("/").on(&handler));
