@@ -1,10 +1,11 @@
-use crate::{block_on, AsyncReadExt, Method};
+use crate::block_on;
 use std::{
     convert::TryInto,
     fmt::Debug,
+    net::IpAddr,
     ops::{Deref, DerefMut},
 };
-use trillium::{http_types::headers::Header, Conn, Handler};
+use trillium::{Conn, Handler, HeaderName, HeaderValues, Method};
 use trillium_http::{Conn as HttpConn, Synthetic};
 
 type SyntheticConn = HttpConn<Synthetic>;
@@ -21,7 +22,7 @@ impl TestConn {
     /**
     constructs a new TestConn with the provided method, path, and body.
     ```
-    use trillium_testing::{TestConn, Method};
+    use trillium_testing::{prelude::*, TestConn};
     let mut conn = TestConn::build("get", "/", "body");
     assert_eq!(conn.method(), Method::Get);
     assert_eq!(conn.path(), "/");
@@ -41,14 +42,20 @@ impl TestConn {
     ```
     use trillium_testing::TestConn;
     let conn = TestConn::build("get", "/", "body")
-        .with_request_header(("some-header", "value"));
-    assert_eq!(conn.headers()["some-header"], "value");
+        .with_request_header("some-header", "value");
+    assert_eq!(conn.headers().get_str("some-header"), Some("value"));
     ```
     */
 
-    pub fn with_request_header(self, header: impl Header) -> Self {
+    pub fn with_request_header(
+        self,
+        header_name: impl Into<HeaderName<'static>>,
+        header_value: impl Into<HeaderValues>,
+    ) -> Self {
         let mut inner: SyntheticConn = self.into();
-        inner.request_headers_mut().apply(header);
+        inner
+            .request_headers_mut()
+            .append(header_name, header_value);
         Self(inner.into())
     }
 
@@ -74,39 +81,21 @@ impl TestConn {
         Self(inner.into())
     }
 
-    /**
-    runs this conn against a handler and finalizes response headers,
-    asynchronously. Since most tests are performed in a sync context,
-    most of the time it is preferable to use [`TestConn::run`], also
-    aliased as [`TestConn::on`]. This function is aliased as
-    [`TestConn::async_on`].
+    /// sets the peer ip for this test conn
+    pub fn with_peer_ip(mut self, ip: IpAddr) -> Self {
+        self.inner_mut().set_peer_ip(Some(ip));
+        self
+    }
 
-    ```
-    use trillium_testing::prelude::*;
-
-    trillium_testing::block_on(async {
-        async fn handler(conn: Conn) -> Conn {
-            conn.ok("hello trillium")
-        }
-
-        let conn = get("/").run_async(&handler).await;
-        assert_ok!(conn, "hello trillium", "content-length" => "14");
-    });
-    ```
-    */
-
-    pub async fn run_async(self, handler: &impl Handler) -> Self {
-        let conn = handler.run(self.into()).await;
-        let mut conn = handler.before_send(conn).await;
-        conn.inner_mut().finalize_headers();
-        Self(conn)
+    /// set the test conn to be secure
+    pub fn secure(mut self) -> Self {
+        self.inner_mut().set_secure(true);
+        self
     }
 
     /**
     blocks on running this conn against a handler and finalizes
-    response headers. also aliased as [`TestConn::on`]. use
-    [`TestConn::run_async`] for the rare circumstances in which
-    testing in an async context is necessary.
+    response headers. also aliased as [`TestConn::on`]
 
     ```
     use trillium_testing::prelude::*;
@@ -123,11 +112,16 @@ impl TestConn {
         block_on(self.run_async(handler))
     }
 
+    async fn run_async(self, handler: &impl Handler) -> Self {
+        let conn = handler.run(self.into()).await;
+        let mut conn = handler.before_send(conn).await;
+        conn.inner_mut().finalize_headers();
+        Self(conn)
+    }
+
     /**
     blocks on running this conn against a handler and finalizes
-    response headers. also aliased as [`TestConn::run`]. use
-    [`TestConn::run_async`] for the rare circumstances in which
-    testing in an async context is necessary.
+    response headers. also aliased as [`TestConn::run`].
 
     ```
     use trillium_testing::prelude::*;
@@ -145,61 +139,24 @@ impl TestConn {
         self.run(handler)
     }
 
-    /**
-    runs this conn against a handler and finalizes response headers,
-    asynchronously. Since most tests are performed in a sync context,
-    most of the time it is preferable to use [`TestConn::run`], also
-    aliased as [`TestConn::on`]. This function is an alias of
-    [`TestConn::run_async`].
-
-    ```
-    use trillium_testing::prelude::*;
-
-    trillium_testing::block_on(async {
-        async fn handler(conn: Conn) -> Conn {
-            conn.ok("hello trillium")
-        }
-
-        let conn = get("/").async_on(&handler).await;
-        assert_ok!(conn, "hello trillium", "content-length" => "14");
-    });
-    ```
-    */
-
-    pub async fn async_on(self, handler: &impl Handler) -> Self {
-        self.run_async(handler).await
-    }
-
     /**
     Reads the response body to string and returns it, if set. This is
     used internally to [`assert_body`] which is the preferred
     interface
     */
-    pub async fn take_response_body_string(&mut self) -> Option<String> {
-        if let Some(mut body) = self.take_response_body() {
-            let mut s = String::new();
-            body.read_to_string(&mut s).await.expect("read");
-            Some(s)
+    pub fn take_response_body_string(&mut self) -> Option<String> {
+        if let Some(body) = self.take_response_body() {
+            String::from_utf8(block_on(body.into_bytes()).unwrap().to_vec()).ok()
         } else {
             None
         }
     }
 
-    // pub fn take_body_bytes(&mut self) -> Option<Vec<u8>> {
-    //     self.take_response_body().map(|mut body| {
-    //         let mut v = Vec::new();
-    //         block_on(body.read_to_end(&mut v)).expect("read");
-    //         v
-    //     })
-    // }
-
     /**
     Reads the request body to string and returns it
     */
     pub fn take_request_body_string(&mut self) -> String {
-        futures_lite::future::block_on(async {
-            self.request_body().await.read_string().await.unwrap()
-        })
+        block_on(async { self.request_body().await.read_string().await.unwrap() })
     }
 }
 
